summaryrefslogtreecommitdiff
path: root/gst-libs
diff options
context:
space:
mode:
authorLasse Laukkanen <ext-lasse.2.laukkanen@nokia.com>2010-10-08 11:33:31 +0300
committerTim-Philipp Müller <tim@centricular.net>2012-07-11 00:10:55 +0100
commit8fd2fc662a7c36a2df4c2621dd88a0951395a820 (patch)
tree7a2577261e42960b32a7d8978da402bed144451f /gst-libs
parent7d41bc7825049dcb4e6902c5bdef851633969188 (diff)
downloadgstreamer-plugins-bad-8fd2fc662a7c36a2df4c2621dd88a0951395a820.tar.gz
photography: Add GstPhotography prefix and fix spelling colour->color
https://bugzilla.gnome.org/show_bug.cgi?id=622482
Diffstat (limited to 'gst-libs')
-rw-r--r--gst-libs/gst/interfaces/photography.c87
-rw-r--r--gst-libs/gst/interfaces/photography.h140
2 files changed, 116 insertions, 111 deletions
diff --git a/gst-libs/gst/interfaces/photography.c b/gst-libs/gst/interfaces/photography.c
index 11f0e71d8..3761a8684 100644
--- a/gst-libs/gst/interfaces/photography.c
+++ b/gst-libs/gst/interfaces/photography.c
@@ -76,7 +76,7 @@ gst_photography_iface_base_init (GstPhotographyInterface * iface)
iface->get_aperture = NULL;
iface->get_exposure = NULL;
iface->get_white_balance_mode = NULL;
- iface->get_colour_tone_mode = NULL;
+ iface->get_color_tone_mode = NULL;
iface->get_scene_mode = NULL;
iface->get_flash_mode = NULL;
iface->get_noise_reduction = NULL;
@@ -89,7 +89,7 @@ gst_photography_iface_base_init (GstPhotographyInterface * iface)
iface->set_aperture = NULL;
iface->set_exposure = NULL;
iface->set_white_balance_mode = NULL;
- iface->set_colour_tone_mode = NULL;
+ iface->set_color_tone_mode = NULL;
iface->set_scene_mode = NULL;
iface->set_flash_mode = NULL;
iface->set_noise_reduction = NULL;
@@ -212,7 +212,7 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (exposure, guint32);
/**
* gst_photography_set_white_balance_mode:
* @photo: #GstPhotography interface of a #GstElement
- * @wb_mode: #GstWhiteBalanceMode to set
+ * @wb_mode: #GstPhotographyWhiteBalanceMode to set
*
* Set the white balance mode for the #GstElement
*
@@ -221,38 +221,39 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (exposure, guint32);
/**
* gst_photography_get_white_balance_mode:
* @photo: #GstPhotography interface of a #GstElement
- * @wb_mode: #GstWhiteBalanceMode to get
+ * @wb_mode: #GstPhotographyWhiteBalanceMode to get
*
* Get the white balance mode for the #GstElement
*
* Returns: %TRUE if getting the value succeeded, %FALSE otherwise
*/
-GST_PHOTOGRAPHY_FUNC_TEMPLATE (white_balance_mode, GstWhiteBalanceMode);
+GST_PHOTOGRAPHY_FUNC_TEMPLATE (white_balance_mode,
+ GstPhotographyWhiteBalanceMode);
/**
- * gst_photography_set_colour_tone_mode:
+ * gst_photography_set_color_tone_mode:
* @photo: #GstPhotography interface of a #GstElement
- * @tone_mode: #GstColourToneMode to set
+ * @tone_mode: #GstPhotographyColorToneMode to set
*
* Set the colour tone mode for the #GstElement
*
* Returns: %TRUE if setting the value succeeded, %FALSE otherwise
*/
/**
- * gst_photography_get_colour_tone_mode:
+ * gst_photography_get_color_tone_mode:
* @photo: #GstPhotography interface of a #GstElement
- * @tone_mode: #GstColourToneMode to get
+ * @tone_mode: #GstPhotographyColorToneMode to get
*
* Get the colour tone mode for the #GstElement
*
* Returns: %TRUE if getting the value succeeded, %FALSE otherwise
*/
-GST_PHOTOGRAPHY_FUNC_TEMPLATE (colour_tone_mode, GstColourToneMode);
+GST_PHOTOGRAPHY_FUNC_TEMPLATE (color_tone_mode, GstPhotographyColorToneMode);
/**
* gst_photography_set_scene_mode:
* @photo: #GstPhotography interface of a #GstElement
- * @scene_mode: #GstSceneMode to set
+ * @scene_mode: #GstPhotographySceneMode to set
*
* Set the scene mode for the #GstElement
*
@@ -261,18 +262,18 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (colour_tone_mode, GstColourToneMode);
/**
* gst_photography_get_scene_mode:
* @photo: #GstPhotography interface of a #GstElement
- * @scene_mode: #GstSceneMode to get
+ * @scene_mode: #GstPhotographySceneMode to get
*
* Get the scene mode for the #GstElement
*
* Returns: %TRUE if getting the value succeeded, %FALSE otherwise
*/
-GST_PHOTOGRAPHY_FUNC_TEMPLATE (scene_mode, GstSceneMode);
+GST_PHOTOGRAPHY_FUNC_TEMPLATE (scene_mode, GstPhotographySceneMode);
/**
* gst_photography_set_flash_mode:
* @photo: #GstPhotography interface of a #GstElement
- * @flash_mode: #GstFlashMode to set
+ * @flash_mode: #GstPhotographyFlashMode to set
*
* Set the flash mode for the #GstElement
*
@@ -281,18 +282,18 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (scene_mode, GstSceneMode);
/**
* gst_photography_get_flash_mode:
* @photo: #GstPhotography interface of a #GstElement
- * @flash_mode: #GstFlashMode to get
+ * @flash_mode: #GstPhotographyFlashMode to get
*
* Get the flash mode for the #GstElement
*
* Returns: %TRUE if getting the value succeeded, %FALSE otherwise
*/
-GST_PHOTOGRAPHY_FUNC_TEMPLATE (flash_mode, GstFlashMode);
+GST_PHOTOGRAPHY_FUNC_TEMPLATE (flash_mode, GstPhotographyFlashMode);
/**
* gst_photography_set_noise_reduction:
* @photo: #GstPhotography interface of a #GstElement
- * @noise_reduction: #GstNoiseReductionMode to set
+ * @noise_reduction: #GstPhotographyNoiseReductionMode to set
*
* Set the noise reduction mode for the #GstElement
*
@@ -303,7 +304,7 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (flash_mode, GstFlashMode);
/**
* gst_photography_get_noise_reduction:
* @photo: #GstPhotography interface of a #GstElement
- * @noise_reduction: #GstNoiseReductionMode to get
+ * @noise_reduction: #GstPhotographyNoiseReductionMode to get
*
* Get the noise reduction mode for the #GstElement
*
@@ -352,7 +353,8 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (zoom, gfloat);
*
* Returns: %TRUE if getting the value succeeded, %FALSE otherwise
*/
-GST_PHOTOGRAPHY_FUNC_TEMPLATE (flicker_mode, GstFlickerReductionMode);
+GST_PHOTOGRAPHY_FUNC_TEMPLATE (flicker_mode,
+ GstPhotographyFlickerReductionMode);
/**
* gst_photography_set_focus_mode:
@@ -372,18 +374,18 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (flicker_mode, GstFlickerReductionMode);
*
* Returns: %TRUE if getting the value succeeded, %FALSE otherwise
*/
-GST_PHOTOGRAPHY_FUNC_TEMPLATE (focus_mode, GstFocusMode);
+GST_PHOTOGRAPHY_FUNC_TEMPLATE (focus_mode, GstPhotographyFocusMode);
/**
* gst_photography_get_capabilities:
* @photo: #GstPhotography interface of a #GstElement
*
* Get #GstPhotoCaps bitmask value that indicates what photography
* interface features the #GstElement supports
*
- * Returns: #GstPhotoCaps value
+ * Returns: #GstPhotographyCaps value
*/
-GstPhotoCaps
+GstPhotographyCaps
gst_photography_get_capabilities (GstPhotography * photo)
{
GstPhotographyInterface *iface;
@@ -411,7 +413,8 @@ gst_photography_get_capabilities (GstPhotography * photo)
*/
gboolean
gst_photography_prepare_for_capture (GstPhotography * photo,
- GstPhotoCapturePrepared func, GstCaps * capture_caps, gpointer user_data)
+ GstPhotographyCapturePrepared func, GstCaps * capture_caps,
+ gpointer user_data)
{
GstPhotographyInterface *iface;
gboolean ret = TRUE;
@@ -449,14 +452,15 @@ gst_photography_set_autofocus (GstPhotography * photo, gboolean on)
/**
* gst_photography_set_config:
* @photo: #GstPhotography interface of a #GstElement
* @config: #GstPhotoSettings containg the configuration
*
* Set all configuration settings at once.
*
* Returns: TRUE if configuration was set successfully, otherwise FALSE.
*/
gboolean
-gst_photography_set_config (GstPhotography * photo, GstPhotoSettings * config)
+gst_photography_set_config (GstPhotography * photo,
+ GstPhotographySettings * config)
{
GstPhotographyInterface *iface;
gboolean ret = FALSE;
@@ -474,14 +478,15 @@ gst_photography_set_config (GstPhotography * photo, GstPhotoSettings * config)
/**
* gst_photography_get_config:
* @photo: #GstPhotography interface of a #GstElement
* @config: #GstPhotoSettings containg the configuration
*
* Get all configuration settings at once.
*
* Returns: TRUE if configuration was got successfully, otherwise FALSE.
*/
gboolean
-gst_photography_get_config (GstPhotography * photo, GstPhotoSettings * config)
+gst_photography_get_config (GstPhotography * photo,
+ GstPhotographySettings * config)
{
GstPhotographyInterface *iface;
gboolean ret = FALSE;
@@ -507,17 +512,17 @@ gst_photography_iface_class_init (gpointer g_class)
g_param_spec_enum (GST_PHOTOGRAPHY_PROP_WB_MODE,
"White balance mode property",
"White balance affects the color temperature of the photo",
- GST_TYPE_WHITE_BALANCE_MODE,
+ GST_TYPE_PHOTOGRAPHY_WHITE_BALANCE_MODE,
GST_PHOTOGRAPHY_WB_MODE_AUTO,
G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
- /* Colour tone */
+ /* Color tone */
g_object_interface_install_property (g_class,
- g_param_spec_enum (GST_PHOTOGRAPHY_PROP_COLOUR_TONE,
- "Colour tone mode property",
- "Colour tone setting changes colour shading in the photo",
- GST_TYPE_COLOUR_TONE_MODE,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_NORMAL,
+ g_param_spec_enum (GST_PHOTOGRAPHY_PROP_COLOR_TONE,
+ "Color tone mode property",
+ "Color tone setting changes color shading in the photo",
+ GST_TYPE_PHOTOGRAPHY_COLOR_TONE_MODE,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_NORMAL,
G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
/* Scene mode */
@@ -525,7 +530,7 @@ gst_photography_iface_class_init (gpointer g_class)
g_param_spec_enum (GST_PHOTOGRAPHY_PROP_SCENE_MODE,
"Scene mode property",
"Scene mode works as a preset for different photo shooting mode settings",
- GST_TYPE_SCENE_MODE,
+ GST_TYPE_PHOTOGRAPHY_SCENE_MODE,
GST_PHOTOGRAPHY_SCENE_MODE_AUTO,
G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
@@ -534,7 +539,7 @@ gst_photography_iface_class_init (gpointer g_class)
g_param_spec_enum (GST_PHOTOGRAPHY_PROP_FLASH_MODE,
"Flash mode property",
"Flash mode defines how the flash light should be used",
- GST_TYPE_FLASH_MODE,
+ GST_TYPE_PHOTOGRAPHY_FLASH_MODE,
GST_PHOTOGRAPHY_FLASH_MODE_AUTO,
G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
@@ -543,7 +548,7 @@ gst_photography_iface_class_init (gpointer g_class)
g_param_spec_enum (GST_PHOTOGRAPHY_PROP_FLICKER_MODE,
"Flicker reduction mode property",
"Flicker reduction mode defines a line frequency for flickering prevention",
- GST_TYPE_FLICKER_REDUCTION_MODE,
+ GST_TYPE_PHOTOGRAPHY_FLICKER_REDUCTION_MODE,
GST_PHOTOGRAPHY_FLICKER_REDUCTION_OFF,
G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
@@ -552,7 +557,7 @@ gst_photography_iface_class_init (gpointer g_class)
g_param_spec_enum (GST_PHOTOGRAPHY_PROP_FOCUS_MODE,
"Focus mode property",
"Focus mode defines the range of focal lengths to use in autofocus search",
- GST_TYPE_FOCUS_MODE,
+ GST_TYPE_PHOTOGRAPHY_FOCUS_MODE,
GST_PHOTOGRAPHY_FOCUS_MODE_AUTO,
G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
@@ -221,38 +221,39 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (exposure, guint32);
*
- * Set the colour tone mode for the #GstElement
+ * Set the color tone mode for the #GstElement
*
* Returns: %TRUE if setting the value succeeded, %FALSE otherwise
@@ -221,38 +221,39 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (exposure, guint32);
*
- * Get the colour tone mode for the #GstElement
+ * Get the color tone mode for the #GstElement
*
* Returns: %TRUE if getting the value succeeded, %FALSE otherwise
@@ -372,18 +374,18 @@ GST_PHOTOGRAPHY_FUNC_TEMPLATE (flicker_mode, GstFlickerReductionMode);
* @photo: #GstPhotography interface of a #GstElement
*
- * Get #GstPhotoCaps bitmask value that indicates what photography
+ * Get #GstPhotographyCaps bitmask value that indicates what photography
* interface features the #GstElement supports
*
@@ -449,14 +452,15 @@ gst_photography_set_autofocus (GstPhotography * photo, gboolean on)
* gst_photography_set_config:
* @photo: #GstPhotography interface of a #GstElement
- * @config: #GstPhotoSettings containg the configuration
+ * @config: #GstPhotographySettings containg the configuration
*
* Set all configuration settings at once.
@@ -474,14 +478,15 @@ gst_photography_set_config (GstPhotography * photo, GstPhotoSettings * config)
* gst_photography_get_config:
* @photo: #GstPhotography interface of a #GstElement
- * @config: #GstPhotoSettings containg the configuration
+ * @config: #GstPhotographySettings containg the configuration
*
* Get all configuration settings at once.
diff --git a/gst-libs/gst/interfaces/photography.h b/gst-libs/gst/interfaces/photography.h
index 21a4a5086..27c55eb73 100644
--- a/gst-libs/gst/interfaces/photography.h
+++ b/gst-libs/gst/interfaces/photography.h
@@ -53,7 +53,7 @@ G_BEGIN_DECLS
/* Interface property names */
#define GST_PHOTOGRAPHY_PROP_WB_MODE "white-balance-mode"
-#define GST_PHOTOGRAPHY_PROP_COLOUR_TONE "colour-tone-mode"
+#define GST_PHOTOGRAPHY_PROP_COLOR_TONE "color-tone-mode"
#define GST_PHOTOGRAPHY_PROP_SCENE_MODE "scene-mode"
#define GST_PHOTOGRAPHY_PROP_FLASH_MODE "flash-mode"
#define GST_PHOTOGRAPHY_PROP_NOISE_REDUCTION "noise-reduction"
@@ -115,23 +115,23 @@ typedef enum
GST_PHOTOGRAPHY_WB_MODE_SUNSET,
GST_PHOTOGRAPHY_WB_MODE_TUNGSTEN,
GST_PHOTOGRAPHY_WB_MODE_FLUORESCENT
-} GstWhiteBalanceMode;
+} GstPhotographyWhiteBalanceMode;
typedef enum
{
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_NORMAL = 0,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_SEPIA,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_NEGATIVE,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_GRAYSCALE,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_NATURAL,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_VIVID,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_COLORSWAP,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_SOLARIZE,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_OUT_OF_FOCUS,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_SKY_BLUE,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_GRASS_GREEN,
- GST_PHOTOGRAPHY_COLOUR_TONE_MODE_SKIN_WHITEN
-} GstColourToneMode;
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_NORMAL = 0,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_SEPIA,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_NEGATIVE,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_GRAYSCALE,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_NATURAL,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_VIVID,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_COLORSWAP,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_SOLARIZE,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_OUT_OF_FOCUS,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_SKY_BLUE,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_GRASS_GREEN,
+ GST_PHOTOGRAPHY_COLOR_TONE_MODE_SKIN_WHITEN
+} GstPhotographyColorToneMode;
typedef enum
{
@@ -142,7 +142,7 @@ typedef enum
GST_PHOTOGRAPHY_SCENE_MODE_SPORT,
GST_PHOTOGRAPHY_SCENE_MODE_NIGHT,
GST_PHOTOGRAPHY_SCENE_MODE_AUTO
-} GstSceneMode;
+} GstPhotographySceneMode;
typedef enum
{
@@ -151,7 +151,7 @@ typedef enum
GST_PHOTOGRAPHY_FLASH_MODE_ON,
GST_PHOTOGRAPHY_FLASH_MODE_FILL_IN,
GST_PHOTOGRAPHY_FLASH_MODE_RED_EYE
-} GstFlashMode;
+} GstPhotographyFlashMode;
typedef enum
{
@@ -159,7 +159,7 @@ typedef enum
GST_PHOTOGRAPHY_FOCUS_STATUS_RUNNING,
GST_PHOTOGRAPHY_FOCUS_STATUS_FAIL,
GST_PHOTOGRAPHY_FOCUS_STATUS_SUCCESS
-} GstFocusStatus;
+} GstPhotographyFocusStatus;
typedef enum
{
@@ -178,14 +178,14 @@ typedef enum
GST_PHOTOGRAPHY_CAPS_NOISE_REDUCTION = (1 << 11),
GST_PHOTOGRAPHY_CAPS_FLICKER_REDUCTION = (1 << 12),
GST_PHOTOGRAPHY_CAPS_ALL = (~0)
-} GstPhotoCaps;
+} GstPhotographyCaps;
typedef enum
{
GST_PHOTOGRAPHY_SHAKE_RISK_LOW = 0,
GST_PHOTOGRAPHY_SHAKE_RISK_MEDIUM,
GST_PHOTOGRAPHY_SHAKE_RISK_HIGH,
-} GstPhotoShakeRisk;
+} GstPhotographyShakeRisk;
typedef enum
{
@@ -193,7 +193,7 @@ typedef enum
GST_PHOTOGRAPHY_FLICKER_REDUCTION_50HZ,
GST_PHOTOGRAPHY_FLICKER_REDUCTION_60HZ,
GST_PHOTOGRAPHY_FLICKER_REDUCTION_AUTO,
-} GstFlickerReductionMode;
+} GstPhotographyFlickerReductionMode;
typedef enum {
GST_PHOTOGRAPHY_FOCUS_MODE_AUTO = 0,
@@ -204,26 +204,26 @@ typedef enum {
GST_PHOTOGRAPHY_FOCUS_MODE_EXTENDED,
GST_PHOTOGRAPHY_FOCUS_MODE_CONTINUOUS_NORMAL,
GST_PHOTOGRAPHY_FOCUS_MODE_CONTINUOUS_EXTENDED,
-} GstFocusMode;
+} GstPhotographyFocusMode;
typedef struct
{
- GstWhiteBalanceMode wb_mode;
- GstColourToneMode tone_mode;
- GstSceneMode scene_mode;
- GstFlashMode flash_mode;
+ GstPhotographyWhiteBalanceMode wb_mode;
+ GstPhotographyColorToneMode tone_mode;
+ GstPhotographySceneMode scene_mode;
+ GstPhotographyFlashMode flash_mode;
guint32 exposure;
guint aperture;
gfloat ev_compensation;
guint iso_speed;
gfloat zoom;
- GstFlickerReductionMode flicker_mode;
- GstFocusMode focus_mode;
+ GstPhotographyFlickerReductionMode flicker_mode;
+ GstPhotographyFocusMode focus_mode;
GstPhotographyNoiseReduction noise_reduction;
-} GstPhotoSettings;
+} GstPhotographySettings;
/**
- * GstPhotoCapturePrepared:
+ * GstPhotographyCapturePrepared:
* @data: user data that has been given, when registering the callback
* @configured_caps: #GstCaps defining the configured capture format.
* Ownership of these caps stays in the element.
@@ -231,7 +231,7 @@ typedef struct
* This callback will be called when the element has finished preparations
* for photo capture.
*/
-typedef void (*GstPhotoCapturePrepared) (gpointer data,
+typedef void (*GstPhotographyCapturePrepared) (gpointer data,
const GstCaps *configured_caps);
/**
@@ -242,7 +242,7 @@ typedef void (*GstPhotoCapturePrepared) (gpointer data,
* @get_aperture: vmethod to get aperture value
* @get_exposure: vmethod to get exposure time value
* @get_white_balance_mode: vmethod to get white balance mode value
* @get_colour_tone_mode: vmethod to get colour tone mode value
* @get_scene_mode: vmethod to get scene mode value
* @get_flash_mode: vmethod to get flash mode value
* @get_noise_reduction: vmethod to get noise reduction mode value
@@ -252,7 +252,7 @@ typedef void (*GstPhotoCapturePrepared) (gpointer data,
* @set_aperture: vmethod to set aperture value
* @set_exposure: vmethod to set exposure time value
* @set_white_balance_mode: vmethod to set white balance mode value
* @set_colour_tone_mode: vmethod to set colour tone mode value
* @set_scene_mode: vmethod to set scene mode value
* @set_flash_mode: vmethod to set flash mode value
* @set_noise_reduction: vmethod to set noise reduction mode value
@@ -276,43 +276,43 @@ typedef struct _GstPhotographyInterface
gboolean (*get_aperture) (GstPhotography * photo, guint * aperture);
gboolean (*get_exposure) (GstPhotography * photo, guint32 * exposure);
gboolean (*get_white_balance_mode) (GstPhotography * photo,
- GstWhiteBalanceMode * wb_mode);
- gboolean (*get_colour_tone_mode) (GstPhotography * photo,
- GstColourToneMode * tone_mode);
+ GstPhotographyWhiteBalanceMode * wb_mode);
+ gboolean (*get_color_tone_mode) (GstPhotography * photo,
+ GstPhotographyColorToneMode * tone_mode);
gboolean (*get_scene_mode) (GstPhotography * photo,
- GstSceneMode * scene_mode);
+ GstPhotographySceneMode * scene_mode);
gboolean (*get_flash_mode) (GstPhotography * photo,
- GstFlashMode * flash_mode);
+ GstPhotographyFlashMode * flash_mode);
gboolean (*get_zoom) (GstPhotography * photo, gfloat * zoom);
- gboolean (*get_flicker_mode) (GstPhotography * photo,
- GstFlickerReductionMode * flicker_mode);
+ gboolean (*get_flicker_mode) (GstPhotography * photo,
+ GstPhotographyFlickerReductionMode * flicker_mode);
gboolean (*get_focus_mode) (GstPhotography * photo,
- GstFocusMode * focus_mode);
+ GstPhotographyFocusMode * focus_mode);
gboolean (*set_ev_compensation) (GstPhotography * photo, gfloat ev_comp);
gboolean (*set_iso_speed) (GstPhotography * photo, guint iso_speed);
gboolean (*set_aperture) (GstPhotography * photo, guint aperture);
gboolean (*set_exposure) (GstPhotography * photo, guint32 exposure);
gboolean (*set_white_balance_mode) (GstPhotography * photo,
- GstWhiteBalanceMode wb_mode);
- gboolean (*set_colour_tone_mode) (GstPhotography * photo,
- GstColourToneMode tone_mode);
+ GstPhotographyWhiteBalanceMode wb_mode);
+ gboolean (*set_color_tone_mode) (GstPhotography * photo,
+ GstPhotographyColorToneMode tone_mode);
gboolean (*set_scene_mode) (GstPhotography * photo,
- GstSceneMode scene_mode);
+ GstPhotographySceneMode scene_mode);
gboolean (*set_flash_mode) (GstPhotography * photo,
- GstFlashMode flash_mode);
+ GstPhotographyFlashMode flash_mode);
gboolean (*set_zoom) (GstPhotography * photo, gfloat zoom);
gboolean (*set_flicker_mode) (GstPhotography * photo,
- GstFlickerReductionMode flicker_mode);
+ GstPhotographyFlickerReductionMode flicker_mode);
gboolean (*set_focus_mode) (GstPhotography * photo,
- GstFocusMode focus_mode);
+ GstPhotographyFocusMode focus_mode);
- GstPhotoCaps (*get_capabilities) (GstPhotography * photo);
+ GstPhotographyCaps (*get_capabilities) (GstPhotography * photo);
gboolean (*prepare_for_capture) (GstPhotography * photo,
- GstPhotoCapturePrepared func, GstCaps *capture_caps, gpointer user_data);
+ GstPhotographyCapturePrepared func, GstCaps *capture_caps, gpointer user_data);
void (*set_autofocus) (GstPhotography * photo, gboolean on);
- gboolean (*set_config) (GstPhotography * photo, GstPhotoSettings * config);
- gboolean (*get_config) (GstPhotography * photo, GstPhotoSettings * config);
+ gboolean (*set_config) (GstPhotography * photo, GstPhotographySettings * config);
+ gboolean (*get_config) (GstPhotography * photo, GstPhotographySettings * config);
gboolean (*get_noise_reduction) (GstPhotography * photo,
GstPhotographyNoiseReduction * noise_reduction);
@@ -335,20 +335,20 @@ gboolean gst_photography_get_aperture (GstPhotography * photo,
gboolean gst_photography_get_exposure (GstPhotography * photo,
guint32 * exposure);
gboolean gst_photography_get_white_balance_mode (GstPhotography * photo,
- GstWhiteBalanceMode * wb_mode);
-gboolean gst_photography_get_colour_tone_mode (GstPhotography * photo,
- GstColourToneMode * tone_mode);
+ GstPhotographyWhiteBalanceMode * wb_mode);
+gboolean gst_photography_get_color_tone_mode (GstPhotography * photo,
+ GstPhotographyColorToneMode * tone_mode);
gboolean gst_photography_get_scene_mode (GstPhotography * photo,
- GstSceneMode * scene_mode);
+ GstPhotographySceneMode * scene_mode);
gboolean gst_photography_get_flash_mode (GstPhotography * photo,
- GstFlashMode * flash_mode);
+ GstPhotographyFlashMode * flash_mode);
gboolean gst_photography_get_noise_reduction (GstPhotography * photo,
GstPhotographyNoiseReduction * noise_reduction);
gboolean gst_photography_get_zoom (GstPhotography * photo, gfloat * zoom);
gboolean gst_photography_get_flicker_mode (GstPhotography * photo,
- GstFlickerReductionMode *mode);
+ GstPhotographyFlickerReductionMode *mode);
gboolean gst_photography_get_focus_mode (GstPhotography * photo,
- GstFocusMode *mode);
+ GstPhotographyFocusMode *mode);
gboolean gst_photography_set_ev_compensation (GstPhotography * photo,
gfloat ev_comp);
@@ -357,32 +357,32 @@ gboolean gst_photography_set_iso_speed (GstPhotography * photo,
gboolean gst_photography_set_aperture (GstPhotography * photo, guint aperture);
gboolean gst_photography_set_exposure (GstPhotography * photo, guint exposure);
gboolean gst_photography_set_white_balance_mode (GstPhotography * photo,
- GstWhiteBalanceMode wb_mode);
-gboolean gst_photography_set_colour_tone_mode (GstPhotography * photo,
- GstColourToneMode tone_mode);
+ GstPhotographyWhiteBalanceMode wb_mode);
+gboolean gst_photography_set_color_tone_mode (GstPhotography * photo,
+ GstPhotographyColorToneMode tone_mode);
gboolean gst_photography_set_scene_mode (GstPhotography * photo,
- GstSceneMode scene_mode);
+ GstPhotographySceneMode scene_mode);
gboolean gst_photography_set_flash_mode (GstPhotography * photo,
- GstFlashMode flash_mode);
+ GstPhotographyFlashMode flash_mode);
gboolean gst_photography_set_noise_reduction (GstPhotography * photo,
GstPhotographyNoiseReduction noise_reduction);
gboolean gst_photography_set_zoom (GstPhotography * photo, gfloat zoom);
gboolean gst_photography_set_flicker_mode (GstPhotography * photo,
- GstFlickerReductionMode mode);
+ GstPhotographyFlickerReductionMode mode);
gboolean gst_photography_set_focus_mode (GstPhotography * photo,
- GstFocusMode mode);
+ GstPhotographyFocusMode mode);
-GstPhotoCaps gst_photography_get_capabilities (GstPhotography * photo);
+GstPhotographyCaps gst_photography_get_capabilities (GstPhotography * photo);
gboolean gst_photography_prepare_for_capture (GstPhotography * photo,
- GstPhotoCapturePrepared func, GstCaps *capture_caps, gpointer user_data);
+ GstPhotographyCapturePrepared func, GstCaps *capture_caps, gpointer user_data);
void gst_photography_set_autofocus (GstPhotography * photo, gboolean on);
gboolean gst_photography_set_config (GstPhotography * photo,
- GstPhotoSettings * config);
+ GstPhotographySettings * config);
gboolean gst_photography_get_config (GstPhotography * photo,
- GstPhotoSettings * config);
+ GstPhotographySettings * config);
G_END_DECLS
@@ -242,7 +242,7 @@ typedef void (*GstPhotoCapturePrepared) (gpointer data,
* @get_exposure: vmethod to get exposure time value
* @get_white_balance_mode: vmethod to get white balance mode value
- * @get_colour_tone_mode: vmethod to get colour tone mode value
+ * @get_color_tone_mode: vmethod to get color tone mode value
* @get_scene_mode: vmethod to get scene mode value
* @get_flash_mode: vmethod to get flash mode value
@@ -252,7 +252,7 @@ typedef void (*GstPhotoCapturePrepared) (gpointer data,
* @set_exposure: vmethod to set exposure time value
* @set_white_balance_mode: vmethod to set white balance mode value
- * @set_colour_tone_mode: vmethod to set colour tone mode value
+ * @set_color_tone_mode: vmethod to set color tone mode value
* @set_scene_mode: vmethod to set scene mode value
* @set_flash_mode: vmethod to set flash mode value